allow multiple __future__ imports in separate statements
[cython.git] / cython.py
old mode 100644 (file)
new mode 100755 (executable)
index f32cf15..5dbd25c
--- a/cython.py
+++ b/cython.py
@@ -1,6 +1,21 @@
+#!/usr/bin/env python
+
 #
#   Pyrex -- Main Program, generic
 #
 
-from Pyrex.Compiler.Main import main
-main(command_line = 1)
+if __name__ == '__main__':
+
+    import os
+    import sys
+    
+    # Make sure we import the right Cython
+    cythonpath, _ = os.path.split(os.path.realpath(__file__))
+    sys.path.insert(0, cythonpath)
+
+    from Cython.Compiler.Main import main
+    main(command_line = 1)
+
+else:
+    # Void cython.* directives.
+    from Cython.Shadow import *
@@ -1,6 +1,21 @@
 #
-#   Pyrex -- Main Program, generic
+#   Cython -- Main Program, generic
 #
 